@@ -1,7 +1,11 @@
-use crate::quickjs_utils::{functions, primitives};
-use crate::quickjsruntime::QuickJsRuntime;
+//! JSValueRef is a wrapper for quickjs's JSValue. it provides automatic reference counting making it safer to use  
+
+use crate::quickjs_utils::typedarrays::is_typed_array;
+use crate::quickjs_utils::{arrays, errors, functions, primitives, promises};
+use crate::quickjsruntimeadapter::QuickJsRuntimeAdapter;
 use hirofa_utils::js_utils::adapters::JsValueAdapter;
 use hirofa_utils::js_utils::facades::JsValueType;
+use hirofa_utils::js_utils::JsError;
 use libquickjs_sys as q;
 use std::hash::{Hash, Hasher};
 use std::ptr::null_mut;
@@ -261,11 +265,11 @@ pub(crate) const TAG_EXCEPTION: i64 = 6;
 pub(crate) const TAG_FLOAT64: i64 = 7;
 
 impl JsValueAdapter for JSValueRef {
-    type JsRuntimeAdapterType = QuickJsRuntime;
+    type JsRuntimeAdapterType = QuickJsRuntimeAdapter;
 
     fn js_get_type(&self) -> JsValueType {
         match self.get_tag() {
-            TAG_EXCEPTION => todo!(),
+            TAG_EXCEPTION => JsValueType::Error,
             TAG_NULL => JsValueType::Null,
             TAG_UNDEFINED => JsValueType::Undefined,
             TAG_BOOL => JsValueType::Boolean,
@@ -273,8 +277,14 @@ impl JsValueAdapter for JSValueRef {
             TAG_FLOAT64 => JsValueType::F64,
             TAG_STRING => JsValueType::String,
             TAG_OBJECT => {
-                if unsafe { functions::is_function(self.context, &self) } {
+                if unsafe { functions::is_function(self.context, self) } {
                     JsValueType::Function
+                } else if unsafe { promises::is_promise(self.context, self) } {
+                    JsValueType::Promise
+                } else if unsafe { errors::is_error(self.context, self) } {
+                    JsValueType::Error
+                } else if unsafe { arrays::is_array(self.context, self) } {
+                    JsValueType::Array
                 } else {
                     JsValueType::Object
                 }
@@ -284,6 +294,10 @@ impl JsValueAdapter for JSValueRef {
         }
     }
 
+    fn js_is_typed_array(&self) -> bool {
+        unsafe { is_typed_array(self.context, self) }
+    }
+
     fn js_type_of(&self) -> &'static str {
         match self.get_tag() {
             TAG_BIG_INT => "bigint",
@@ -337,13 +351,63 @@ impl JsValueAdapter for JSValueRef {
         }
     }
 
-    fn js_to_string(&self) -> String {
+    fn js_to_string(&self) -> Result<String, JsError> {
+        match self.js_get_type() {
+            JsValueType::I32 => Ok(self.js_to_i32().to_string()),
+            JsValueType::F64 => Ok(self.js_to_f64().to_string()),
+            JsValueType::String => unsafe { primitives::to_string(self.context, self) },
+            JsValueType::Boolean => {
+                if self.js_to_bool() {
+                    Ok("true".to_string())
+                } else {
+                    Ok("false".to_string())
+                }
+            }
+            JsValueType::Error => {
+                let js_error = unsafe { errors::error_to_js_error(self.context, self) };
+                Ok(format!("{}", js_error))
+            }
+            _ => unsafe { functions::call_to_string(self.context, self) },
+        }
+    }
+
+    fn js_to_str(&self) -> Result<&str, JsError> {
         if self.js_get_type() == JsValueType::String {
-            unsafe { primitives::to_string(self.context, self) }
-                .ok()
-                .expect("could not convert to string")
+            unsafe { primitives::to_str(self.context, self) }
         } else {
-            panic!("not a string");
+            Err(JsError::new_str("this value is not a string"))
         }
     }
 }
+
+#[cfg(test)]
+pub mod tests {
+    use crate::facades::tests::init_test_rt;
+    use hirofa_utils::js_utils::adapters::JsValueAdapter;
+    use hirofa_utils::js_utils::facades::JsValueType;
+    use hirofa_utils::js_utils::Script;
+
+    #[test]
+    fn test_to_str() {
+        let rt = init_test_rt();
+        rt.exe_rt_task_in_event_loop(|q_js_rt| {
+            let q_ctx = q_js_rt.get_main_context();
+            let res = q_ctx.eval(Script::new("test_to_str.es", "('hello ' + 'world');"));
+
+            match res {
+                Ok(res) => {
+                    log::info!("script ran ok: {:?}", res);
+                    assert!(res.js_get_type() == JsValueType::String);
+                    assert_eq!(
+                        res.js_to_str().ok().expect("str conv failed"),
+                        "hello world"
+                    );
+                }
+                Err(e) => {
+                    log::error!("script failed: {}", e);
+                    panic!("script failed");
+                }
+            }
+        });
+    }
+}
